@@ -32,13 +32,11 @@ const Page = {
     CITY: 1
 };
 
-const MainWindow = new Lang.Class({
+var MainWindow = new Lang.Class({
     Name: 'MainWindow',
     Extends: Gtk.ApplicationWindow,
 
     _init: function(params) {
-        params = Params.fill(params, { width_request: 700,
-                                       height_request: 520 });
         this.parent(params);
 
         this._world = this.application.world;
@@ -72,7 +70,7 @@ const MainWindow = new Lang.Class({
         this._searchView = builder.get_object('initial-grid');
 
         this._searchEntry = builder.get_object('initial-grid-location-entry');
-        this._searchEntry.connect('notify::location', Lang.bind(this, this._searchLocationChanged));
+        this._searchEntry.connect('notify::location', this._searchLocationChanged.bind(this));
 
         let placesButton = builder.get_object('places-button');
         this._pageWidgets[Page.CITY].push(placesButton);
