@@ -23,11 +23,12 @@ const Gtk = imports.gi.Gtk;
 const GWeather = imports.gi.GWeather;
 const Lang = imports.lang;
 
+const CurrentLocationController = imports.app.currentLocationController;
 const Params = imports.misc.params;
 const Util = imports.misc.util;
 
 
-const WorldContentView = new Lang.Class({
+var WorldContentView = new Lang.Class({
     Name: 'WorldContentView',
     Extends: Gtk.Popover,
 
@@ -47,7 +48,7 @@ const WorldContentView = new Lang.Class({
         this._window = window;
 
         this._listbox = builder.get_object('locations-list-box');
-        this._listbox.set_header_func(function (row, previous) {
+        this._listbox.set_header_func((row, previous) => {
             let hasHeader = row.get_header() != null;
             let shouldHaveHeader = previous != null;
             if (hasHeader != shouldHaveHeader) {
@@ -59,69 +60,59 @@ const WorldContentView = new Lang.Class({
         });
 
         let locationEntry = builder.get_object('location-entry');
-        locationEntry.connect('notify::location', Lang.bind(this, this._locationChanged));
+        locationEntry.connect('notify::location', this._locationChanged.bind(this));
 
-        this.connect('show', Lang.bind(this, function() {
+        this.connect('show', () => {
             locationEntry.grab_focus();
-        }));
+        });
 
         let autoLocStack = builder.get_object('auto-location-stack');
         let autoLocSwitch = builder.get_object('auto-location-switch');
         let currentLocationController = application.currentLocationController;
 
-        if(currentLocationController.autoLocation) {
+        if(currentLocationController.autoLocation == CurrentLocationController.AutoLocation.ENABLED) {
             autoLocStack.visible_child_name = 'locating-label';
         } else {
             autoLocStack.visible_child_name = 'auto-location-switch-grid';
             autoLocSwitch.active = false;
+            autoLocSwitch.sensitive = (currentLocationController.autoLocation != CurrentLocationController.AutoLocation.NOT_AVAILABLE);
         }
 
-        let handlerId = autoLocSwitch.connect('notify::active', Lang.bind(this, function() {
+        let handlerId = autoLocSwitch.connect('notify::active', () => {
             currentLocationController.setAutoLocation(autoLocSwitch.active);
 
             if (autoLocSwitch.active && !this.model.addedCurrentLocation)
                 autoLocStack.visible_child_name = 'locating-label';
 
             this.hide();
-        }));
+        });
 
-        this._listbox.connect('row-activated', Lang.bind(this, function(listbox, row) {
+        this._listbox.connect('row-activated', (listbox, row) => {
             this.hide();
             this.model.moveLocationToFront(row._info);
             this._window.showInfo(row._info, false);
-        }));
+        });
 
-        this.model.connect('current-location-changed', Lang.bind(this, function(model, info) {
+        this.model.connect('current-location-changed', (model, info) => {
             autoLocStack.visible_child_name = 'auto-location-switch-grid';
-            if (info.location) {
-                GObject.signal_handler_block(autoLocSwitch, handlerId);
-                autoLocSwitch.active = true;
-                GObject.signal_handler_unblock(autoLocSwitch, handlerId);
-            } else {
-                GObject.signal_handler_block(autoLocSwitch, handlerId);
-                autoLocSwitch.active = false;
-                GObject.signal_handler_unblock(autoLocSwitch, handlerId);
-
-                autoLocSwitch.sensitive = false;
-            }
+            GObject.signal_handler_block(autoLocSwitch, handlerId);
+            autoLocSwitch.active = (currentLocationController.autoLocation == CurrentLocationController.AutoLocation.ENABLED);
+            autoLocSwitch.sensitive = (currentLocationController.autoLocation != CurrentLocationController.AutoLocation.NOT_AVAILABLE);
+            GObject.signal_handler_unblock(autoLocSwitch, handlerId);
 
             this._window.showInfo(info, true);
-        }));
+        });
 
         this._stackPopover = builder.get_object('popover-stack');
-        this._listbox.set_filter_func(Lang.bind(this, this._filterListbox));
+        this._listbox.set_filter_func(this._filterListbox.bind(this));
 
-        this.model.connect('location-added', Lang.bind(this, this._onLocationAdded));
-        this.model.connect('location-removed', Lang.bind(this, this._onLocationRemoved));
+        this.model.connect('location-added', this._onLocationAdded.bind(this));
+        this.model.connect('location-removed', this._onLocationRemoved.bind(this));
 
         this._currentLocationAdded = false;
-        if (this.model.length > 0) {
-            let list = this.model.getAll();
-            for (let i = list.length - 1; i >= 0; i--)
-                this._onLocationAdded(this.model, list[i], list[i]._isCurrentLocation);
-        } else {
-            this.model.load();
-        }
+        let list = this.model.getAll();
+        for (let i = list.length - 1; i >= 0; i--)
+            this._onLocationAdded(this.model, list[i], list[i]._isCurrentLocation);
     },
 
     refilter: function() {
@@ -215,10 +206,10 @@ const WorldContentView = new Lang.Class({
         if (info._updatedId)
             return;
 
-        info._updatedId = info.connect('updated', Lang.bind(this, function(info) {
+        info._updatedId = info.connect('updated', (info) => {
             tempLabel.label = info.get_temp_summary();
             image.icon_name = info.get_symbolic_icon_name();
-        }));
+        });
 
         this._syncStackPopover();
     },
