@@ -1,6 +1,11 @@
 # -*- mode: python -*-
 
 from gi.repository import GLib, Gio
+
+from dogtail.utils import isA11yEnabled, enableA11y
+if not isA11yEnabled():
+    enableA11y(True)
+
 from dogtail import tree
 from dogtail import utils
 from dogtail.predicate import *
@@ -66,7 +71,7 @@ def reset_settings():
 def init():
     global settings, _previous_locations
 
-    settings = Gio.Settings(schema_id="org.gnome.Weather.Application")
+    settings = Gio.Settings("org.gnome.Weather.Application")
     _previous_locations = settings.get_value("locations")
     reset_settings()
 
